Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3417)

Unified Diff: ash/rotator/screen_rotation_animator.h

Issue 2790583004: Add second copy request after screen rotation to flatten the layers in animation. (Closed)
Patch Set: Rebased and fixed a bug. Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ash/rotator/screen_rotation_animator.h
diff --git a/ash/rotator/screen_rotation_animator.h b/ash/rotator/screen_rotation_animator.h
index ce77673d356d949614e4d4f6714cc5ee5bc0b357..e8abc1fd3dcc8ffcd50c3e0a9b65af5e4c99d21b 100644
--- a/ash/rotator/screen_rotation_animator.h
+++ b/ash/rotator/screen_rotation_animator.h
@@ -14,7 +14,12 @@
#include "base/observer_list.h"
#include "ui/display/display.h"
+namespace aura {
+class Window;
+} // namesapce aura
+
namespace cc {
+class CopyOutputRequest;
class CopyOutputResult;
} // namespace cc
@@ -65,17 +70,25 @@ class ASH_EXPORT ScreenRotationAnimator {
base::Callback<void(std::unique_ptr<cc::CopyOutputResult> result)>;
struct ScreenRotationRequest {
ScreenRotationRequest(int64_t id,
+ display::Display::Rotation from_rotation,
display::Display::Rotation to_rotation,
display::Display::RotationSource from_source)
- : id(id), new_rotation(to_rotation), source(from_source) {}
+ : id(id),
+ old_rotation(from_rotation),
+ new_rotation(to_rotation),
+ source(from_source) {}
int64_t id;
+ display::Display::Rotation old_rotation;
display::Display::Rotation new_rotation;
display::Display::RotationSource source;
};
// This function can be overridden in unit test to test removing external
// display.
- virtual CopyCallback CreateAfterCopyCallback(
+ virtual CopyCallback CreateAfterCopyCallbackBeforeRotation(
+ std::unique_ptr<ScreenRotationRequest> rotation_request);
+
+ virtual CopyCallback CreateAfterCopyCallbackAfterRotation(
std::unique_ptr<ScreenRotationRequest> rotation_request);
oshima 2017/04/17 15:25:23 looks to me that you're not really using both in t
wutao 2017/04/17 23:30:31 Added two more tests to remove display before the
private:
@@ -84,20 +97,38 @@ class ASH_EXPORT ScreenRotationAnimator {
void StartRotationAnimation(
std::unique_ptr<ScreenRotationRequest> rotation_request);
- // This is an asynchronous call to request copy output of root layer.
- void RequestCopyRootLayerAndAnimateRotation(
+ // The fallback to slow animation if copy output request cancled or failed.
+ void StartSlowAnimation(
std::unique_ptr<ScreenRotationRequest> rotation_request);
- // The callback in |RequestCopyRootLayerAndAnimateRotation()|.
- void OnRootLayerCopiedBeforeRotation(
+ // A wrapper to call |display_manager| to set screen rotation and rotate the
+ // |old_layer_tree| to the |old_rotation|.
+ void SetRotation(display::Display::Rotation old_rotation,
+ display::Display::Rotation new_rotation,
+ display::Display::RotationSource source);
+
+ // This is an asynchronous call to request copy output of root layer.
+ void RequestCopyScreenRotationContainerLayer(
+ std::unique_ptr<cc::CopyOutputRequest> copy_output_request);
+
+ // The callback in |RequestCopyScreenRotationContainerLayer()| before screen
+ // rotation.
+ void OnScreenRotationContainerLayerCopiedBeforeRotation(
+ std::unique_ptr<ScreenRotationRequest> rotation_request,
+ std::unique_ptr<cc::CopyOutputResult> result);
+
+ // The callback in |RequestCopyScreenRotationContainerLayer()| after screen
+ // rotation.
+ void OnScreenRotationContainerLayerCopiedAfterRotation(
std::unique_ptr<ScreenRotationRequest> rotation_request,
std::unique_ptr<cc::CopyOutputResult> result);
// Recreates all |root_window| layers.
void CreateOldLayerTree();
- // Requests a copy of |root_window| root layer output.
- void CopyOldLayerTree(std::unique_ptr<cc::CopyOutputResult> result);
+ // Creates a new layer and its layer tree owner from |CopyOutputResult|.
+ std::unique_ptr<ui::LayerTreeOwner> CopyLayerTree(
+ std::unique_ptr<cc::CopyOutputResult> result);
// Note: Only call this function when the |old_layer_tree_owner_| is set up
// properly.
@@ -108,7 +139,13 @@ class ASH_EXPORT ScreenRotationAnimator {
// |rotation_degrees| arc.
void AnimateRotation(std::unique_ptr<ScreenRotationRequest> rotation_request);
- void set_disable_animation_timers_for_test(bool disable_timers);
+ void set_disable_animation_timers_for_test(bool disable_timers) {
+ disable_animation_timers_for_test_ = disable_timers;
+ }
+
+ void set_switch_smooth_rotation_for_test(bool enable) {
+ has_switch_ash_enable_smooth_screen_rotation_ = enable;
+ }
void StopAnimating();
@@ -135,7 +172,11 @@ class ASH_EXPORT ScreenRotationAnimator {
base::ObserverList<ScreenRotationAnimatorObserver>
screen_rotation_animator_observers_;
std::unique_ptr<ui::LayerTreeOwner> old_layer_tree_owner_;
+ std::unique_ptr<ui::LayerTreeOwner> new_layer_tree_owner_;
std::unique_ptr<ScreenRotationRequest> last_pending_request_;
+ bool has_switch_ash_enable_smooth_screen_rotation_;
+ aura::Window* root_window_;
+ ui::Layer* screen_rotation_container_layer_;
base::WeakPtrFactory<ScreenRotationAnimator> weak_factory_;
DISALLOW_COPY_AND_ASSIGN(ScreenRotationAnimator);
@@ -84,20 +97,38 @@ class ASH_EXPORT ScreenRotationAnimator {
std::unique_ptr<ScreenRotationRequest> rotation_request,
std::unique_ptr<cc::CopyOutputResult> result);
- // Recreates all |root_window| layers.
+ // Recreates all |root_window| layers and their layer tree owner.
void CreateOldLayerTree();

Powered by Google App Engine
This is Rietveld 408576698